@@ -21,13 +21,12 @@
 #' @export
 chk_numeric <- function(x, x_name = NULL) {
   if (vld_numeric(x)) {
-    return(invisible())
+    return(invisible(x))
   }
   if (is.null(x_name)) x_name <- deparse_backtick_chk((substitute(x)))
   abort_chk(x_name, " must be numeric", x = x)
 }
 
-
 #' @describeIn chk_numeric Validate Numeric
 #'
 #' @examples
