@@ -17,7 +17,7 @@
 #' @export
 chk_s4_class <- function(x, class, x_name = NULL) {
   if (vld_s4_class(x, class)) {
-    return(invisible())
+    return(invisible(x))
   }
   if (is.null(x_name)) x_name <- deparse_backtick_chk(substitute(x))
   abort_chk(x_name, " must inherit from S4 class '", class, "'", x = x, class = class)
