@@ -14,3 +14,9 @@
 
   anyDuplicated(x)
 }
+
+# remove when no longer support R < 3.6.0
+str2lang <- function(text) {
+  ex <- parse(text=text, keep.source=FALSE)
+  ex[[1L]]
+}
