@@ -1,5 +1,3 @@
-context("chk-date")
-
 test_that("vld_date", {
   expect_false(vld_date(NULL))
   expect_false(vld_date(as.Date("2000-01-01")[-1]))
@@ -8,7 +6,7 @@ test_that("vld_date", {
 })
 
 test_that("chk_date", {
-  expect_null(chk_date(as.Date("2000-01-01")))
+  expect_identical(chk_date(as.Date("2000-01-01")), as.Date("2000-01-01"))
   expect_invisible(chk_date(as.Date("2000-01-01")))
 
   expect_chk_error(chk_date(1), "^`1` must be a date [(]non-missing Date scalar[)][.]$")
